/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.bind;

import java.util.HashMap;

import net.lucubrators.honeycomb.core.bind.BinderProvider;
import net.lucubrators.honeycomb.core.bind.exceptions.UnknownBinderException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DefaultBinderProvider implements BinderProvider {
	private static final Logger log = LoggerFactory.getLogger(DefaultBinderProvider.class);

	private final HashMap<String, Object> binders;

	public DefaultBinderProvider() {
		binders = new HashMap<String, Object>();
	}

	@Override
	public Object getBinder(final String id) throws UnknownBinderException {
		Object object = binders.get(id);
		if (object != null) {
			return object;
		}
		throw new UnknownBinderException("Unknown Binder with id: " + id);
	}

	@Override
	public void addBinder(final String id, final Object binder) {
		if (binders.containsKey(id)) {
			log.warn("You are about to overwrite an exisiting binder with id: {}", id);
		}
		binders.put(id, binder);
	}

}
