/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.controller;

import java.util.Map;

import net.lucubrators.honeycomb.core.controller.Populate;
import net.lucubrators.honeycomb.core.shared.Model;
import net.lucubrators.honeycomb.core.shared.annotations.CombAttributes;
import net.lucubrators.honeycomb.core.view.View;
import net.lucubrators.honeycomb.defaultimpl.view.JSPView;

/**
 * An example of a possible controller
 * 
 * @author aglomann
 * 
 */
public class GenericJSPViewController {

	private final boolean exposeModel;
	private final String viewAttributeName;
	private final String viewPrefix;
	private final String viewSuffix;

	/**
	 * Constructor
	 * 
	 * @param exposeModel
	 *            true if the attributes of the comb should be exposed to the
	 *            model
	 * @param viewAttributeName
	 *            the full path of the jsp which should be included
	 */
	public GenericJSPViewController(final boolean exposeModel, final String viewAttributeName) {
		this(exposeModel, viewAttributeName, "", "");
	}

	/**
	 * Convinience Constructor
	 * 
	 * @param exposeModel
	 *            true if the attributes of the comb should be exposed to the
	 *            model
	 * @param viewAttributeName
	 *            the path of the jsp without prefix or suffix
	 * @param viewPrefix
	 *            to prepend to the name of the jsp
	 * @param viewSuffix
	 *            to append to the name of the jsp
	 */
	public GenericJSPViewController(final boolean exposeModel, final String viewAttributeName, final String viewPrefix, final String viewSuffix) {
		this.exposeModel = exposeModel;
		this.viewAttributeName = viewAttributeName;
		if (null == viewPrefix || null == viewSuffix) {
			throw new IllegalArgumentException("ViewPrefix or ViewSuffix must not be null");
		}
		this.viewPrefix = viewPrefix;
		this.viewSuffix = viewSuffix;
	}

	/**
	 * Populates the view on a get request
	 * 
	 * @param model
	 *            the implicit model
	 * @param attributes
	 *            all comb attributes
	 * @return a {@link JSPView} which renders the given jsp
	 */
	@Populate
	public View populate(Model model, @CombAttributes final Map<String, String> attributes) {
		String viewPath = attributes.get(viewAttributeName);
		if (null == viewPath) {
			throw new IllegalArgumentException("View is not defined in attribute " + viewAttributeName + " is null");
		}
		if (exposeModel) {
			model.putAll(attributes);
		}
		return new JSPView(viewPrefix + attributes.get(viewAttributeName) + viewSuffix);
	}

}
