/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.reflect;

import java.lang.annotation.Annotation;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import net.lucubrators.honeycomb.core.reflect.exceptions.CombInvocationException;
import net.lucubrators.honeycomb.core.reflect.exceptions.IllegalControllerException;
import net.lucubrators.honeycomb.defaultimpl.reflect.MethodHolder;
import net.lucubrators.honeycomb.defaultimpl.reflect.MethodInvoker;

/**
 * Default implementation of a {@link MethodInvoker}
 * 
 * @author gnalFF
 * 
 */
public class DefaultMethodInvoker implements MethodInvoker {

	@Override
	public Object invokeMethod(final MethodHolder<? extends Annotation> controllerMethod, final Object[] arguments) throws CombInvocationException {
		Method method = controllerMethod.getMethod();
		try {
			return method.invoke(controllerMethod.getContainer(), arguments);
		} catch (IllegalArgumentException e) {
			throw new IllegalControllerException("Could not invoke controller method : " + method, e);
		} catch (IllegalAccessException e) {
			throw new IllegalControllerException("Could not invoke controller method : " + method, e);
		} catch (InvocationTargetException e) {
			CombInvocationException combInvocationException = new CombInvocationException("Exception occured whild invoking method annotated with "
					+ controllerMethod.getAnnotation()
					+ " in Object " + controllerMethod.getContainer());
			combInvocationException.initCause(e.getCause());
			throw combInvocationException;
		}
	}

}
