/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.reflect;

import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.util.List;

import net.lucubrators.honeycomb.defaultimpl.util.GenericType;

/**
 * Holder object for the class of a method parameter, its {@link GenericType}
 * and all its applied annotations.
 * 
 * @author gnalFF
 * 
 */
public final class MethodArgument {

	private Type type;
	private List<? extends Annotation> annotations;
	private Class<?> argumentClass;

	public MethodArgument(final Class<?> argumentClass, final Type type, final List<? extends Annotation> annotations) {
		this.argumentClass = argumentClass;
		this.type = type;
		this.annotations = annotations;
	}

	public Class<?> getArgumentClass() {
		return argumentClass;
	}

	public Type getType() {
		return type;
	}

	@SuppressWarnings("unchecked")
	public List<Annotation> getAnnotations() {
		return (List<Annotation>) annotations;
	}

	@Override
	public String toString() {
		return "MethodArgument [annotations=" + annotations + ", argumentClass=" + argumentClass + ", type=" + type + "]";
	}

}
