/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.web.tag;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.jsp.JspException;

import net.lucubrators.honeycomb.core.controller.ControllerResult;
import net.lucubrators.honeycomb.core.messages.ErrorMessage;
import net.lucubrators.honeycomb.core.messages.Message;
import net.lucubrators.honeycomb.core.messages.MessageLevel;

/**
 * Print errors which happened while binding
 * 
 * @author gnalFF
 * 
 */
public class DisplayErrorMessagesTag extends BaseCombTag {

	private String	property;
	private String	errorsClass	= "errors";
	private String	errorClass	= "error";

	@Override
	public void internalDoTag() throws JspException, IOException {
		ControllerResult currentResult = getCurrentControllerResult();

		List<Message> messagesByLevel = currentResult.getMessages().getMessagesByLevel(MessageLevel.ERROR);
		if (messagesByLevel.isEmpty()) {
			return;
		}

		List<ErrorMessage> toBeDisplayed = new ArrayList<ErrorMessage>();
		for (Message message : messagesByLevel) {
			ErrorMessage err = (ErrorMessage) message;
			String errorProp = err.getProperty();
			if (getProperty().equals("*") || getProperty().equals(errorProp) || getProperty().startsWith(errorProp.replace(".*", ""))) {
				toBeDisplayed.add(err);
			}
		}
		if (toBeDisplayed.isEmpty()) {
			return;
		}

		getWriter().write("<div class=\"" + getErrorsClass() + "\">");
		for (ErrorMessage message : toBeDisplayed) {
			getWriter().write("<p class=\"" + getErrorClass() + "\">");
			getWriter().write(message.getMessage());
			getWriter().write("</p>");
		}
		getWriter().write("</div>");
	}

	/**
	 * Set the property for which you want to be the error printed
	 * 
	 * @param property
	 *            the name of the property. or "*" to show all errors. it is
	 *            also possible to have all sub property errors displayed
	 *            ("property.*")
	 */
	public void setProperty(final String property) {
		this.property = property;
	}

	public String getProperty() {
		return property;
	}

	/**
	 * The the style class for an error
	 * 
	 * @param errorClass
	 */
	public void setErrorClass(final String errorClass) {
		this.errorClass = errorClass;
	}

	public String getErrorClass() {
		return errorClass;
	}

	/**
	 * Set the style class for the error container
	 * 
	 * @param errorsClass
	 */
	public void setErrorsClass(final String errorsClass) {
		this.errorsClass = errorsClass;
	}

	public String getErrorsClass() {
		return errorsClass;
	}
}
