/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.defaultimpl.web.tag;

import java.io.IOException;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.PageContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import net.lucubrators.honeycomb.core.controller.ControllerResult;
import net.lucubrators.honeycomb.core.util.ControllerResultUtil;
import net.lucubrators.honeycomb.core.view.View;
import net.lucubrators.honeycomb.core.view.ViewContext;
import net.lucubrators.honeycomb.core.view.exceptions.CombRenderingException;

/**
 * Handles rendering for all submarks
 * 
 * @author gnalFF
 * 
 */
public class RenderMarkContentsTag extends BaseCombTag implements ViewContext {
	
	private static Logger log = LoggerFactory.getLogger(RenderMarkContentsTag.class);

	private String	mark;

	@Override
	public void internalDoTag() throws JspException, IOException {
		ControllerResult currentResult = getCurrentControllerResult();
		List<ControllerResult> list = currentResult.getMarks().get(getMark());
		if (list == null || list.isEmpty()) {
			return;
		}
		for (ControllerResult controllerResult : list) {
			View view = controllerResult.getView();
			ControllerResultUtil.setCurrentResult(getRequest(), controllerResult);
			view.render(this);
		}
		ControllerResultUtil.setCurrentResult(getRequest(), currentResult);
	}

	public void setMark(final String mark) {
		this.mark = mark;
	}

	public String getMark() {
		return mark;
	}

	@Override
	public ControllerResult getControllerResult() {
		return getCurrentControllerResult();
	}

	@Override
	public void include(final String path) {
		PageContext pc = (PageContext) getJspContext();
		try {
			pc.include(path, true);
		} catch (ServletException e) {
			log.error("Could not include {}",path,e);
			throw new CombRenderingException("could not include path: " + path, e);
		} catch (IOException e) {
			log.error("Could not include {}",path,e);
			throw new CombRenderingException("could not include path: " + path, e);
		}
	}

	@Override
	public void write(final String toWrite) {
		JspWriter out = getJspContext().getOut();
		try {
			out.write(toWrite);
		} catch (IOException e) {
			throw new CombRenderingException("could not flush or write to writer", e);
		}
	}

	@Override
	public HttpServletResponse getResponse() {
		return (HttpServletResponse) ((PageContext)getJspContext()).getResponse();
	}
}
