/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.web.defaultimpl.translator;

import javax.servlet.http.HttpServletRequest;

import net.lucubrators.honeycomb.web.defaultimpl.translator.RequestToCombIdTranslator;

/**
 * A default implementation of {@link RequestToCombIdTranslator}
 * 
 * @author gnalFF
 * 
 */
public class UriToCombIdTranslator implements RequestToCombIdTranslator {

	private final String suffix;
	private final String welcomeComb;

	public UriToCombIdTranslator() {
		this(".html");
	}

	/**
	 * Constructor
	 * 
	 * @param suffix
	 *            the suffix which should be stripped while translating. The
	 *            welcome comb id will be set to "index"
	 */
	public UriToCombIdTranslator(final String suffix) {
		this(suffix, "index");
	}

	/**
	 * Constructor
	 * 
	 * @param suffix
	 *            the suffix which should be stripped while translating
	 * @param welcomeComb
	 *            the id which should be returned if the uri is just "/" (aka
	 *            welcome file in web.xml)
	 */
	public UriToCombIdTranslator(final String suffix, final String welcomeComb) {
		this.suffix = suffix;
		this.welcomeComb = welcomeComb;
	}

	/**
	 * Translate from the current request uri to a comb id, by stripping the
	 * servlet context, if any. It also strips the provided suffix. If the uri
	 * equals "/" the welcomeComb id will be returned.(Note that the welcomeComb
	 * will only be translated if you did map the filter to "/",too);
	 */
	@Override
	public String translate(final HttpServletRequest request) {
		String servletPath = request.getServletPath();
		if ("/".equals(servletPath)) {
			return welcomeComb;
		}
		if (servletPath.startsWith("/")) {
			servletPath = servletPath.substring(1);
		}
		return servletPath.replace(suffix, "");
	}

}
